# Development Setup

## IDE Settings

VSCode

```json:settings.json
{
  "[python]": {
    "editor.defaultFormatter": "charliermarsh.ruff"
  },
  "editor.formatOnSave": true,
  "python.analysis.typeCheckingMode": "standard"
}
```
